@@ -351,7 +351,7 @@ void instancedefaults(objinstptr newinst, objectptr thisobj, int x, int y)
 {
    newinst->position.x = x;
    newinst->position.y = y;
-   newinst->rotation = 0;
+   newinst->rotation = 0.0;
    newinst->scale = 1.0;
    newinst->style = LINE_INVARIANT;
    newinst->thisobject = thisobj;
@@ -405,7 +405,7 @@ void drawdot(int xpos, int ypos)
 
 void labeldefaults(labelptr newlabel, u_char dopin, int x, int y)
 {
-   newlabel->rotation = 0;
+   newlabel->rotation = 0.0;
    newlabel->color = areawin->color;
    newlabel->scale = areawin->textscale;
    newlabel->string = (stringpart *)malloc(sizeof(stringpart));
@@ -422,7 +422,7 @@ void labeldefaults(labelptr newlabel, u_char dopin, int x, int y)
    else if (dopin == GLOBAL) newlabel->color = GLOBALPINCOLOR;
    else if (dopin == INFO) newlabel->color = INFOLABELCOLOR;
 
-   newlabel->justify = areawin->justify;
+   newlabel->anchor = areawin->anchor;
    newlabel->position.x = x;
    newlabel->position.y = y;
 }
@@ -451,8 +451,8 @@ void textbutton(u_char dopin, int x, int y)
    labeldefaults(*newlabel, dopin, userpt.x, userpt.y);
 
    tmpheight = (short)(TEXTHEIGHT * (*newlabel)->scale);
-   userpt.y -= ((*newlabel)->justify & NOTBOTTOM) ?
-	(((*newlabel)->justify & TOP) ? tmpheight : tmpheight / 2) : 0;
+   userpt.y -= ((*newlabel)->anchor & NOTBOTTOM) ?
+	(((*newlabel)->anchor & TOP) ? tmpheight : tmpheight / 2) : 0;
    areawin->origin.x = userpt.x;
    areawin->origin.y = userpt.y;
    areawin->textpos = 1;  /* Text position is *after* the font declaration */
@@ -847,6 +847,7 @@ Boolean labeltext(int keypressed, char *clientdata)
       oparamptr ops;
       stringpart *newpart;
       Boolean errcond = False;
+      TextLinesInfo tlinfo;
 
       /* erase first before redrawing unless the string is empty */
       undrawtext(curlabel);
@@ -854,8 +855,13 @@ Boolean labeltext(int keypressed, char *clientdata)
       /* Get text width first.  Don't back up over spaces;  this	*/
       /* allows the margin width to be padded out with spaces.		*/
 
-      if (keypressed == MARGINSTOP)
-	 tmpext = ULength(curlabel, areawin->topinstance, areawin->textpos, NULL);
+      if (keypressed == MARGINSTOP) {
+	 tlinfo.dostop = areawin->textpos;
+	 tlinfo.tbreak = NULL;
+	 tlinfo.padding = NULL;
+	 tmpext = ULength(curlabel, areawin->topinstance, &tlinfo);
+	 if (tlinfo.padding != NULL) free(tlinfo.padding);
+      }
 
       if (locpos > 0) {
 	 if (keypressed == MARGINSTOP) {
@@ -1016,34 +1022,34 @@ void textreturn()
    labeltext(TEXT_RETURN, (char *)1);
 }
 
-/*-------------------------------------*/
-/* Change the justification of a label */
-/*-------------------------------------*/
+/*--------------------------------------*/
+/* Change the anchoring of a label	*/
+/*--------------------------------------*/
 
-void rejustify(short mode)
+void reanchor(short mode)
 {
    labelptr curlabel = NULL;
    short    *tsel;
    short jsave;
    Boolean preselected = False, changed = False;
-   static short transjust[] = {15, 13, 12, 7, 5, 4, 3, 1, 0};
+   static short transanchor[] = {15, 13, 12, 7, 5, 4, 3, 1, 0};
 
    if (eventmode == TEXT_MODE || eventmode == ETEXT_MODE) {
       curlabel = TOLABEL(EDITPART);
       UDrawTLine(curlabel);
       undrawtext(curlabel);
-      jsave = curlabel->justify;
-      curlabel->justify = transjust[mode] |
-		(curlabel->justify & NONJUSTFIELD);
-      if (jsave != curlabel->justify) {
-	 register_for_undo(XCF_Justify, UNDO_MORE, areawin->topinstance,
+      jsave = curlabel->anchor;
+      curlabel->anchor = transanchor[mode] |
+		(curlabel->anchor & NONANCHORFIELD);
+      if (jsave != curlabel->anchor) {
+	 register_for_undo(XCF_Anchor, UNDO_MORE, areawin->topinstance,
 			(genericptr)curlabel, (int)jsave);
 	 changed = True;
       }
       redrawtext(curlabel);
       UDrawTLine(curlabel);
 
-      setfontmarks(-1, curlabel->justify);
+      setfontmarks(-1, curlabel->anchor);
    }
    else {
       if (areawin->selects == 0) {
@@ -1056,12 +1062,12 @@ void rejustify(short mode)
 	      areawin->selects; tsel++) {
 	 if (SELECTTYPE(tsel) == LABEL) {
 	    curlabel = SELTOLABEL(tsel);
-            jsave = curlabel->justify;
+            jsave = curlabel->anchor;
 	    undrawtext(curlabel);
-      	    curlabel->justify = transjust[mode] |
-		(curlabel->justify & NONJUSTFIELD);
-            if (jsave != curlabel->justify) {
-	       register_for_undo(XCF_Justify, UNDO_MORE, areawin->topinstance,
+      	    curlabel->anchor = transanchor[mode] |
+		(curlabel->anchor & NONANCHORFIELD);
+            if (jsave != curlabel->anchor) {
+	       register_for_undo(XCF_Anchor, UNDO_MORE, areawin->topinstance,
 			(genericptr)curlabel, (int)jsave);
 	       changed = True;
 	    }
@@ -1073,7 +1079,7 @@ void rejustify(short mode)
 	 draw_all_selected();
    }
    if (curlabel == NULL)
-      Wprintf("No labels chosen to rejustify");
+      Wprintf("No labels chosen to reanchor");
    else if (changed) {
       pwriteback(areawin->topinstance);
       calcbbox(areawin->topinstance);
