@@ -62,7 +62,7 @@ u_char param_select[] = {
    POLYGON | SPLINE | LABEL | OBJINST | ARC,	/* P_POSITION_X */
    POLYGON | SPLINE | LABEL | OBJINST | ARC,	/* P_POSITION_Y */
    POLYGON | SPLINE | ARC | PATH,		/* P_STYLE */
-   LABEL,					/* P_JUSTIFY */
+   LABEL,					/* P_ANCHOR */
    ARC,						/* P_ANGLE1 */
    ARC,						/* P_ANGLE2 */
    ARC,						/* P_RADIUS */
@@ -90,7 +90,7 @@ Widget *param_buttons[] = {
    &ParametersPositionButton,		/* P_POSITION_X */
    &ParametersPositionButton,		/* P_POSITION_Y */
    &ParametersStyleButton,		/* P_STYLE */
-   &ParametersJustificationButton,	/* P_JUSTIFY */
+   &ParametersAnchoringButton,		/* P_ANCHOR */
    &ParametersStartAngleButton,		/* P_ANGLE1 */
    &ParametersEndAngleButton,		/* P_ANGLE2 */
    &ParametersRadiusButton,		/* P_RADIUS */
@@ -820,11 +820,11 @@ int epsubstitute(genericptr thiselem, objectptr thisobj, objinstptr pinst,
 		  break;
 	    }
 	    break;
-	 case P_JUSTIFY:
+	 case P_ANCHOR:
 	    retval = max(retval, 1);
 	    switch(thiselem->type) {
 	       case LABEL:
-		  TOLABEL(&thiselem)->justify = ival;
+		  TOLABEL(&thiselem)->anchor = ival;
 		  break;
 	    }
 	    break;
@@ -869,10 +869,10 @@ int epsubstitute(genericptr thiselem, objectptr thisobj, objinstptr pinst,
 	    retval = max(retval, 1);
 	    switch(thiselem->type) {
 	       case LABEL:
-		  TOLABEL(&thiselem)->rotation = ival;
+		  TOLABEL(&thiselem)->rotation = fval;
 		  break;
 	       case OBJINST:
-		  TOOBJINST(&thiselem)->rotation = ival;
+		  TOOBJINST(&thiselem)->rotation = fval;
 		  break;
 	    }
 	    break;
@@ -1151,10 +1151,10 @@ void pwriteback(objinstptr thisinst)
 		           break;
 	             }
 	             break;
-	          case P_JUSTIFY:
+	          case P_ANCHOR:
 	             switch(thiselem->type) {
 	                case LABEL:
-		           wtemp.ival = TOLABEL(eptr)->justify;
+		           wtemp.ival = TOLABEL(eptr)->anchor;
 		           break;
 	             }
 	             break;
@@ -1189,10 +1189,10 @@ void pwriteback(objinstptr thisinst)
 	          case P_ROTATION:
 	             switch(thiselem->type) {
 	                case OBJINST:
-		           wtemp.ival = TOOBJINST(eptr)->rotation;
+		           wtemp.fval = TOOBJINST(eptr)->rotation;
 		           break;
 	                case LABEL:
-		           wtemp.ival = TOLABEL(eptr)->rotation;
+		           wtemp.fval = TOLABEL(eptr)->rotation;
 		           break;
 	             }
 	             break;
@@ -1750,11 +1750,12 @@ void makenumericalp(genericptr *gelem, u_int mode, char *key, short cycle)
 	       case P_POSITION_Y:
 	          newops->parameter.ivalue = (int)TOLABEL(gelem)->position.y;
 	          break;
-	       case P_JUSTIFY:
-	          newops->parameter.ivalue = (int)TOLABEL(gelem)->justify;
+	       case P_ANCHOR:
+	          newops->parameter.ivalue = (int)TOLABEL(gelem)->anchor;
 	          break;
 	       case P_ROTATION:
-	          newops->parameter.ivalue = (int)TOLABEL(gelem)->rotation;
+	          newops->type = XC_FLOAT;
+	          newops->parameter.fvalue = TOLABEL(gelem)->rotation;
 	          break;
 	       case P_SCALE:
 	          newops->type = XC_FLOAT;
@@ -1802,7 +1803,8 @@ void makenumericalp(genericptr *gelem, u_int mode, char *key, short cycle)
 	          newops->parameter.ivalue = (int)TOOBJINST(gelem)->position.y;
 	          break;
 	       case P_ROTATION:
-	          newops->parameter.ivalue = (int)TOOBJINST(gelem)->rotation;
+	          newops->type = XC_FLOAT;
+	          newops->parameter.fvalue = TOOBJINST(gelem)->rotation;
 	          break;
 	       case P_SCALE:
 	          newops->type = XC_FLOAT;
@@ -2396,11 +2398,21 @@ void unmakeparam(labelptr thislabel, stringpart *thispart)
 
    /* Delete the "PARAM_END" off of the copied string and link it into	*/
    /* the existing string.						*/
+   /* (NOTE:  If parameter is an empty string, there may be nothing	*/
+   /* before PARAM_END. . .)						*/
 
-   for (endpart = newstr; endpart->nextpart->type != PARAM_END;
-	endpart = endpart->nextpart);
-   free(endpart->nextpart);
-   endpart->nextpart = thispart->nextpart;
+   if (newstr->type != PARAM_END) {
+      for (endpart = newstr; endpart->nextpart->type != PARAM_END;
+	   endpart = endpart->nextpart);
+      free(endpart->nextpart);
+      endpart->nextpart = thispart->nextpart;
+   }
+   else {
+      endpart = newstr;
+      newstr = newstr->nextpart;
+      free(endpart);
+      endpart = NULL;
+   }
 
    /* Find the stringpart before the parameter call (if any) */
 
@@ -2416,7 +2428,7 @@ void unmakeparam(labelptr thislabel, stringpart *thispart)
    free(strptr);
 
    /* Merge strings at boundaries, if possible. */
-   mergestring(endpart);
+   if (endpart) mergestring(endpart);
    mergestring(lastpart);
 
    redrawtext(thislabel);
